#
# spec file for package perl-Statistics-Descriptive
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Statistics-Descriptive
Name:           perl-Statistics-Descriptive
Version:        3.0801
Release:        1.7
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Module of basic descriptive statistical functions
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SH/SHLOMIF/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(List::MoreUtils)
BuildRequires:  perl(Module::Build) >= 0.280000
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(parent)
Requires:       perl(List::MoreUtils)
Requires:       perl(parent)
%{perl_requires}

%description
This module provides basic functions used in descriptive statistics. It has
an object oriented design and supports two different types of data storage
and calculation objects: sparse and full. With the sparse method, none of
the data is stored and only a few statistical measures are available. Using
the full method, the entire data set is retained and additional functions
are available.

Whenever a division by zero may occur, the denominator is checked to be
greater than the value '$Statistics::Descriptive::Tolerance', which
defaults to 0.0. You may want to change this value to some small positive
value such as 1e-24 in order to obtain error messages in case of very small
denominators.

Many of the methods (both Sparse and Full) cache values so that subsequent
calls with the same arguments are faster.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README UserSurvey.txt
%license LICENSE

%changelog
* Mon Jul  3 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.0801
  see /usr/share/doc/packages/perl-Statistics-Descriptive/Changes
  3.0801      2023-07-02
  - Correct typos
  - https://github.com/shlomif/perl-Statistics-Descriptive/pull/8
  - thanks to @anirvan
* Sun Oct 18 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.0800
  see /usr/share/doc/packages/perl-Statistics-Descriptive/Changes
  3.0800      2020-10-17
  - dist.ini / weaver.ini / .tidyallrc / etc. cleanup
  - Move to @SHLOMIF
  - Inspired by Lady_Aleena (Thanks!)
  v0.2.1      2015-04-28
  - Specify minimal version of perl to 5.8.x.
  - CPANTS / Kwalitee
  - Add provides to META.yml.
  - CPANTS / Kwalitee
  v0.2.0      2015-03-09
  - Remove dependency on Moo/MooX/MooX::late.
  - Seemed like an overkill for such a small and simple app.
  - Remove dependency on List::MoreUtils.
  - To avoid unnecessary deps.
  v0.0.5      2015-01-25
  - Add inc/ to the git repo, so minting a new release.
  v0.0.4      2014-05-04
  - Add minimal prereq on Getopt::Long 2.36 for GetOptionsFromArray.
  - There were test failures with older Getopt::Long-s.
  v0.0.3      2014-05-02
  - Convert t/app.t from IPC::System::Simple to Test::Trap hoping to
    fix test failures on MS Windows.
  - we also don't use a separate process now but rather capture
    STDOUT.
  v0.0.2      2014-05-01
  - Change the meta resources/links to point to the actual repository at
    GitHub.
  - Thanks to pyon from Freenode for noticing it.
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 3.0702
  see /usr/share/doc/packages/perl-Statistics-Descriptive/Changes
  3.0702      2018-10-25
  - Rephrase some lacking phrasing in the docs.
  - https://github.com/shlomif/perl-Statistics-Descriptive/issues/5
  - Thanks to @melak .
* Tue Jul 17 2018 coolo@suse.com
- updated to 3.0701
  see /usr/share/doc/packages/perl-Statistics-Descriptive/Changes
  3.0701      2018-07-14
  - Typo corrections thanks to Debian
* Sat Jul 14 2018 coolo@suse.com
- updated to 3.0700
  see /usr/share/doc/packages/perl-Statistics-Descriptive/Changes
  3.0700      2018-07-13
  - Typo corrections thanks to Debian
  - Added the ->summary() method to Statistics::Descriptive::Full.
  - https://rt.cpan.org/Public/Bug/Display.html?id=82852
  - Thanks to Su-Shee
* Thu May  3 2018 coolo@suse.com
- updated to 3.0613
  see /usr/share/doc/packages/perl-Statistics-Descriptive/Changes
  3.0613      2018-05-02
  - Convert to Dist-Zilla.
* Wed Jan 13 2016 coolo@suse.com
- updated to 3.0612
  see /usr/share/doc/packages/perl-Statistics-Descriptive/Changes
  3.0612      2016-01-09
  - Move the VCS repository to GitHub.
  - People are more used to it, and it can take part in the CPAN pull-req
    challenge.
  3.0611      2016-01-07
  - Apply patch from Debian to correct a spelling error.
  - https://rt.cpan.org/Ticket/Display.html?id=110987
  - Thanks to Salvatore Bonaccorso for the report and patch.
  3.0610      2016-01-06
  - Clarified the docs for add_data_with_samples().
  - Some people thought they were repeat counts of the data , but they
    are normally ignored.
  - Replace remaining tabs with spaces.
* Sun Jun 21 2015 coolo@suse.com
- updated to 3.0609
  see /usr/share/doc/packages/perl-Statistics-Descriptive/Changes
  3.0609      2015-06-19
  - Update some old URLs and addresses.
* Fri Mar 27 2015 stephan.barth@suse.com
- Fixed broken link.
* Sat Feb  7 2015 coolo@suse.com
- updated to 3.0608
  - Apply patch to speed up skewness calculations.
  - https://rt.cpan.org/Public/Bug/Display.html?id=101422
  - Thanks to Shawn (SLAFFAN).
* Sun Feb  9 2014 coolo@suse.com
- updated to 3.0607
  - Fix the List::MoreUtils prereqs.
  - http://www.cpantesters.org/cpan/report/365b752c-8adf-11e3-bd14-e3bee4621ba3
  - Thanks to Chris Williams (BINGOS) for the CPAN Testers Report.
  - Implement the median_absolute_deviation method.
  - https://bitbucket.org/shlomif/perl-statistics-descriptive/pull-request/5/median-absolute-deviation-method/diff
  - Thanks to Kang-min Liu.
  - Minimal version of perl set to 5.6.0 (CPANTS).
  - Add standalone LICENSE file (CPANTS).
* Tue Jun  4 2013 coolo@suse.com
- updated to 3.0605
  - Add t/style-trailing-space.t .
  - Add t/cpan-changes.t .
  - Convert Changes to it.
  - Correct a misspelling of "weight" in
    lib/Statistics/Descriptive/Smoother/Weightedexponential.pm
  - Thanks to Wilhelm for the report.
  - Update the scripts/tag-release.pl file for Mercurial.
  - Use in_between to compare decimal numbers
  - Smoothing tests were failing because of rounding problems
  - Thanks to Andreas J. König for reporting it and to
    Fabio Ponciroli for fixing it.
  - Correct a typo:
  - https://rt.cpan.org/Ticket/Display.html?id=77145
  - Thanks to Salvatore Bonaccorso and the Debian Perl Group
    for the report.
  - No longer using Test::Exception in the tests.
  - It was used by the tests and not specified in
    test_requires/build_requires.
  - Thanks to hsk@fli-leibniz.de for the report.
  - Add the smoothing functionality.
  - Add the following public methods: add_data_with_samples(),
    set_smoother(), get_smoothed_data() to the main module.
  - Add the lib/Statistics/Descriptive/Smoother.pm and
    lib/Statistics/Descriptive/Smoother/Exponential.pm
    lib/Statistics/Descriptive/Smoother/Weightedexponential.pm
    modules.
  - Thanks to Fabio Ponciroli
  - Add the scripts/bump-version-number.pl to facilitate bumping the
    version number.
  - Add the get_data_without_outliers() and the set_outlier_filter()
    methods.
  - See https://bitbucket.org/barbasa/perl-statistics-descriptive/overview
  - Thanks to Fabio Ponciroli
* Fri Feb 17 2012 coolo@suse.com
- updated to 3.0300
  - Now mean() and median() and other routines return undef() if there are
  no data.
  - Somewhat incompatible change: some methods that returned undef() under
  list context now return an empty list (so it will be false).
  - it is generally not recommended to call such methods in list context
    as they should always be called in scalar context.
  - Resolves https://rt.cpan.org/Ticket/Display.html?id=74693
  - thanks to Shawn Laffan for the report and the patch.
  - Fix https://rt.cpan.org/Ticket/Display.html?id=72495 .
  - percentile should not die and should return undef if there are
    no elements in the collection.
* Mon Dec 19 2011 coolo@suse.de
- update to 3.0202
  - Moved tag-release.pl to scripts/tag-release.pl (though we now use
    Mercurial instead of Subversion.)
  - Add t/mode.t to test the ->mode() method.
  - Documented ->mode() better.
  - Optimized ->mode().
  - Add some documentation clarifying the 0th percentile return, as it
    returns undef() for representing -inf:
  - Fix https://rt.cpan.org/Ticket/Display.html?id=62055
  - Thanks to Dave Breimann for reporting it.
  - Add the tag-release.pl to tag a release using Subversion.
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Aug  4 2010 chris@computersalat.de
- initial package 3.0200
  * created by cpanspec 1.78
